function nBytesWritten = cportputint( H, X, nbyte );

% nBytesWritten = cportputint( H, X, nbyte ) writes integer words to a 
% previously opened serial or parallel port. The parameters are:
% 
% Input:
% ------
%   H     - The port handle returned by cportopen.
%   X     - A numeric array containing the data to be written.
%   nbyte - The number of bytes in a word (default 2).
%
% Output:
% -------
%   nBytesWritten   - Number of bytes written to the port (optional).
%
% The bit order is lowest to highest, real and imaginary interleaved
%
error('CPORTPUTINT is implemented in a MEX file.');
